==> haskell-pointed-5.0.1-53-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-pointed.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pointed
version: 5.0.1
id: pointed-5.0.1-JaHSrMuMoLEBDgzi2VTY2N
key: pointed-5.0.1-JaHSrMuMoLEBDgzi2VTY2N
license: BSD-3-Clause
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/pointed/
synopsis: Pointed and copointed data
description:
    Pointed and copointed data.
category: Data
abi: f9d68ed5e126e68e9d914e53e7e20735
exposed: True
exposed-modules:
    Data.Copointed Data.Pointed
import-dirs: /usr/lib/ghc-8.4.3/site-local/pointed-5.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/pointed-5.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/pointed-5.0.1
hs-libraries: HSpointed-5.0.1-JaHSrMuMoLEBDgzi2VTY2N
depends:
    base-4.11.1.0 comonad-5.0.4-3ZzpO59XP2v9ynT2g1eEnH
    containers-0.5.11.0
    data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    kan-extensions-5.2-JHA8YsYA6RZ844IobJLc24
    semigroupoids-5.3.1-GftqxfO19MMH8grpvmvONx stm-2.4.5.0
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    unordered-containers-0.2.9.0-KPgljVKoY3VBKTw1tFbcre
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             comonad-5.0.4-3ZzpO59XP2v9ynT2g1eEnH=73ea1c02e78d1366c378f0246c151a40
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j=82e1626338bbe81f5b3354a12d7a2c38
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             kan-extensions-5.2-JHA8YsYA6RZ844IobJLc24=b8fc20207a34c0f4e5dad35d3d608411
             semigroupoids-5.3.1-GftqxfO19MMH8grpvmvONx=66c322814c5a6541c0713134ceca4e93
             stm-2.4.5.0=4e743cb5a370ac3fbade528432951c3f
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=8fe746d31ebcf312c14c2777ca0f137c
             unordered-containers-0.2.9.0-KPgljVKoY3VBKTw1tFbcre=264f905ec4c04eb05b5ff3d7321fae90
haddock-interfaces: /usr/share/doc/haskell-pointed/html/pointed.haddock
haddock-html: /usr/share/doc/haskell-pointed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pointed-5.0.1-54-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-pointed.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pointed
version: 5.0.1
id: pointed-5.0.1-6t8xLPIY4N15Zihr9MrOAi
key: pointed-5.0.1-6t8xLPIY4N15Zihr9MrOAi
license: BSD-3-Clause
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/pointed/
synopsis: Pointed and copointed data
description:
    Pointed and copointed data.
category: Data
abi: dad26bd2efa9745734ccfe859a8f58e9
exposed: True
exposed-modules:
    Data.Copointed Data.Pointed
import-dirs: /usr/lib/ghc-8.4.3/site-local/pointed-5.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/pointed-5.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/pointed-5.0.1
hs-libraries: HSpointed-5.0.1-6t8xLPIY4N15Zihr9MrOAi
depends:
    base-4.11.1.0 comonad-5.0.4-3ZzpO59XP2v9ynT2g1eEnH
    containers-0.5.11.0
    data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    kan-extensions-5.2-2cbOVjjpACjKvIVFVTxVZh
    semigroupoids-5.3.1-HnAehqim391AnbE6GNyZx5 stm-2.4.5.0
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    unordered-containers-0.2.9.0-KPgljVKoY3VBKTw1tFbcre
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             comonad-5.0.4-3ZzpO59XP2v9ynT2g1eEnH=73ea1c02e78d1366c378f0246c151a40
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j=82e1626338bbe81f5b3354a12d7a2c38
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             kan-extensions-5.2-2cbOVjjpACjKvIVFVTxVZh=462206ec0bb9ec9149df16d44310153c
             semigroupoids-5.3.1-HnAehqim391AnbE6GNyZx5=5a2fccf4d02ab283783d02328c35f83d
             stm-2.4.5.0=4e743cb5a370ac3fbade528432951c3f
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=8fe746d31ebcf312c14c2777ca0f137c
             unordered-containers-0.2.9.0-KPgljVKoY3VBKTw1tFbcre=264f905ec4c04eb05b5ff3d7321fae90
haddock-interfaces: /usr/share/doc/haskell-pointed/html/pointed.haddock
haddock-html: /usr/share/doc/haskell-pointed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
